@@ -37,6 +37,8 @@ usage:
       pub.subscribe(CONFIG, configHandler)
 
       pub.publish(CONFIG, config_data)
+
+      if pub.hasSubscriber(CONFIG):
 """
 class pub(object):
 
@@ -79,7 +81,12 @@ class pub(object):
             for item in pub.topics[pub.topic_list[topic]]:
                 if item[1] == address:
                     Thread(target=item[0], args=[*argv]).start()
-        
+
+    @staticmethod
+    def hasSubscriber(topic):
+        if pub.topic_list[topic] in pub.topics:
+            return True
+        return False
 
 
 class Interface(object):
@@ -166,6 +173,9 @@ class Interface(object):
         """ persistent data storage for Interface """
         self._ifaceData = Custom(self, 'idata')  # Interface data
 
+        """ persistent storage for Notices """
+        self.Notices = Custom(self, 'notices')
+
         try:
             self.network_interface = self.getNetworkInterface()
             LOGGER.info('Connect: Network Interface: {}'.format(
@@ -415,7 +425,6 @@ class Interface(object):
                 self._server, self._port))
             self._mqttc.loop_stop()
             self._mqttc.disconnect()
-        pub.publish(self.STOP, None)
 
     def send(self, message, type):
         """
@@ -583,6 +592,7 @@ class Interface(object):
             except ValueError as e:
                 value = item.get('value')
 
+            self.Notices.load(value)
             pub.publish(self.NOTICES, None, value)
         elif key == 'getIsyInfo':
             pub.publish(self.ISY, None, item)
@@ -595,12 +605,13 @@ class Interface(object):
             """
             try:
                 if item.get('key') == 'customparamsdoc':
-                    pub.publish(self.CUSTOMPARAMSDOC, None, item.get('value'))
+                    pubpublish(self.CUSTOMPARAMSDOC, None, item.get('value'))
                 else:
                     value = json.loads(item.get('value'))
 
                     #LOGGER.error('GETALL -> {} {}'.format(item.get('key'), value))
                     if item.get('key') == 'notices':
+                        self.Notices.load(value)
                         pub.publish(self.NOTICES, None, value)
                     elif item.get('key') == 'customparams':
                         pub.publish(self.CUSTOMPARAMS, None, value)
@@ -649,7 +660,9 @@ class Interface(object):
                 self.status()
         elif key == 'stop':
             LOGGER.info('Received stop from Polyglot... Shutting Down.')
-            self.stop()
+            pub.publish(self.STOP, None)
+            if not pub.hasSubscriber(self.STOP):
+                self.stop()
         elif key == 'setLogLevel':
             try:
                 self.currentLogLevel = item['level'].upper()
